# NBAGrapher

NBA Grapher is a python script that can make plots and graphs of NBA comparing various statistical measures of NBA players and teams

NBA Grapher uses either [sportsreference](https://github.com/roclark/sportsreference) or [basketball_reference_scraper](https://github.com/vishaalagartha/basketball_reference_scraper) for scraping data from [basketball-reference](http://basketball-reference.com) and creates plots using [matplotlib](https://matplotlib.org/)

Currently, scatter plot, shot charts and radial plots are supported. See [Examples](Examples.md) for more details

Details on the functions can be found in the full [documentation](https://nbagrapher.readthedocs.io/en/latest/)

A full list of avaiable statistics for each function can be found [here](https://nbagrapher.readthedocs.io/en/latest/#list-of-available-stats).

---
### Installation
NBAGrapher can be installed from PyPi using PIP
```sh
$ pip install nbagrapher
```
----
### Examples


-----
License
----

MIT


